#!/bin/bash

# updated by WIBOON 2556-04-17

exitusage() 
{
  echo "usage: sudo sh $0 username [option]"
  echo "option:"
  echo "       -y          = add username from freeradius database"
  echo "       -p password = add username with password"
  # option -p password is program for bulknetuseradd.sh
  exit 
}

if [ -z "$(id -nG|grep -w "root")" ] ; then
  echo "need root, or try: sudo sh $0"
  exit
fi
if [ "$1" = "--help" ] ; then
  exitusage
fi
if [ -z "$1" ] ; then
  echo "need username"
  exitusage 
fi
if [ ! -z "$(getent passwd $1)" ] ; then
  echo "username exist"
  exit
fi
if [ "$2" = "-y" ] ; then
  USER_RADIUS="yes"
else
  USER_RADIUS="no"
fi
if [ "$2" = "-p" ] ; then
  GEN_PASSWORD="yes"
  if [ -z "$3" ] ; then
     echo "need password"
     exitusage
  else
     PASSWD=$3
  fi
else
  GEN_PASSWORD="no"
fi

MYUSER=$1
HOME_DIR="/sftp/home"
HOME_WWW_RESTRICT="/var/www/noname"
HOME_WWW_PUBLIC="/var/www/ishare"
README_FILE="DO_NOT_UPLOAD_HERE.txt"
FOLDER_PRIVATE="private"
FOLDER_RESTRICT="noname"
FOLDER_PUBLIC="ishare"
WWW_OWN="www-data"

echo "(1/4) Adding user and user to group member, group sftponly."
if [ "${USER_RADIUS}" = "no" ] ; then
  if [ "${GEN_PASSWORD}" = "no" ] ; then
     sudo useradd -m -b ${HOME_DIR} -s /bin/bash ${MYUSER}
     RC=$?
     if [ ${RC} != 0 ] ; then
       exit ${RC}
     fi
     echo "Please set password of ${MYUSER}"
     sudo passwd ${MYUSER}
  else
     sudo useradd -m -b ${HOME_DIR} -s /bin/bash -p `mkpasswd ${PASSWD}` ${MYUSER}
     RC=$?
     if [ ${RC} != 0 ] ; then
       exit ${RC}
     fi
  fi
else
  sudo useradd -m -b ${HOME_DIR} -s /bin/bash ${MYUSER}
  RC=$?
  if [ ${RC} != 0 ] ; then
    exit ${RC}
  fi
fi
sudo chmod -R o-rwx ${HOME_DIR}/${MYUSER}
sudo gpasswd -a ${MYUSER} member
sudo gpasswd -a ${MYUSER} sftponly

echo "(2/4) Setting file and group permission."
sudo mkdir -m 770 ${HOME_DIR}/${MYUSER}/${FOLDER_PRIVATE}
sudo mkdir -m 771 ${HOME_DIR}/${MYUSER}/${FOLDER_RESTRICT}
sudo mkdir -m 775 ${HOME_DIR}/${MYUSER}/${FOLDER_PUBLIC}
sudo chmod 555 ${HOME_DIR}/${MYUSER}
sudo chown -R ${MYUSER}:${MYUSER} ${HOME_DIR}/${MYUSER}/*
sudo chown -R ${MYUSER}:${WWW_OWN} ${HOME_DIR}/${MYUSER}/${FOLDER_RESTRICT}

echo "(3/4) Linking file from home to www directory."
sudo ln -s ${HOME_DIR}/${MYUSER}/${FOLDER_RESTRICT} ${HOME_WWW_RESTRICT}/${MYUSER}
sudo ln -s ${HOME_DIR}/${MYUSER}/${FOLDER_PUBLIC} ${HOME_WWW_PUBLIC}/${MYUSER}
sudo ln ${HOME_DIR}/${README_FILE} ${HOME_DIR}/${MYUSER}/

echo "(4/4) Set user disk quota."
if [ -z "$(grep usrquota /etc/fstab)" ] ; then
  echo "Disk quota system is not install. This required additional steps already set up."
  echo "User disk quota is not set yet."
else
  # 2048000=2GB, 5120000=5GB, 20480000=20GB
  Q_HDD=5120000
  SHOWQ_HDD=$(( ${Q_HDD} / 1024000 ))
  echo "Setting user disk quota limit: ${Q_HDD} ($SHOWQ_HDD GB)."
  sudo setquota -u ${MYUSER} 0 ${Q_HDD} 0 0 -a
  echo "Current disk quota ${MYUSER}:"
  sudo repquota -s -a | egrep "Space limits|User|-----|^${MYUSER} "
  echo "To view all user quotas: sudo repquota -sa"
fi
echo ""
echo "User ${MYUSER} was added successfully."
echo ""
